lume :fire: [![ci](https://github.com/alice-biometrics/lume/workflows/ci/badge.svg)](https://github.com/alice-biometrics/lume/actions) [![pypi](https://img.shields.io/pypi/dm/lume)](https://pypi.org/project/lume/)
=====

Lume helps you with your daily dev operations and ease the CI & CD process.

## Installation :computer:

~~~
pip install lume
~~~

## Getting Started :chart_with_upwards_trend:	

**lume** is a framework that give us a .....


```console
lume -h
```

```console
LUME_CONFIG_FILENAME=examples/echo-lume.yml; lume -h
```
